#!/usr/bin/env python
# -*- coding: utf-8 -*-


import dbus, sys
from dbus.mainloop.glib import DBusGMainLoop

DBusGMainLoop(set_as_default=True)

def init():
	"""
	Preconnection instructions
	"""
	global bus
	bus = dbus.SystemBus()

def get_poisson_vpn():
	"""
	Obtain DBus object for the poisson vpn connection
	"""
	proxy = bus.get_object("org.freedesktop.NetworkManagerUserSettings",
						   "/org/freedesktop/NetworkManagerSettings")
	interface = dbus.Interface(proxy, "org.freedesktop.NetworkManagerSettings")
	
	c = None
	for connection in interface.ListConnections():
		proxy = bus.get_object("org.freedesktop.NetworkManagerUserSettings",
							   connection)
		settings = proxy.GetSettings(dbus_interface="org.freedesktop.NetworkManagerSettings.Connection")
		if (settings['connection']['type'] == "vpn" and settings['connection']['id'] == "Poisson"):
			c = connection
	
	# Check if VPN is already active
	proxy = bus.get_object("org.freedesktop.NetworkManager", "/org/freedesktop/NetworkManager")
	interface = dbus.Interface(proxy, "org.freedesktop.DBus.Properties")
	for connection in interface.Get("org.freedesktop.NetworkManager", "ActiveConnections"):
		proxy = bus.get_object("org.freedesktop.NetworkManager", connection)
		interface = dbus.Interface(proxy, "org.freedesktop.DBus.Properties")
		connection = interface.Get("org.freedesktop.NetworkManager.Connection.Active", "Connection")
		if connection == c:
			return None
	return c
	
def get_base_connection():
	"""
	Obtain active connection
	"""
	proxy = bus.get_object("org.freedesktop.NetworkManager",
						   "/org/freedesktop/NetworkManager")
	interface = dbus.Interface(proxy, "org.freedesktop.DBus.Properties")
	active_connections = interface.Get('org.freedesktop.NetworkManager', 'ActiveConnections')
	
	for connection in active_connections:
		proxy = bus.get_object("org.freedesktop.NetworkManager",
							   connection)
		interface = dbus.Interface(proxy, "org.freedesktop.DBus.Properties")
		path = interface.Get('org.freedesktop.NetworkManager.Connection.Active', 'Connection')

		proxy = bus.get_object('org.freedesktop.NetworkManagerUserSettings',
							   path)
		interface = dbus.Interface(proxy, 'org.freedesktop.NetworkManagerSettings.Connection')
		settings = interface.GetSettings()
		if settings.has_key("802-11-wireless"):
			# PHC-wifi
			if settings['802-11-wireless']['seen-bssids'][0] == u'00:0f:cb:aa:16:52':
				return connection
				
	return None
	
	
def activate_connection(connection):
	"""
	Activate connection
	"""
	proxy = bus.get_object("org.freedesktop.NetworkManager",
						   "/org/freedesktop/NetworkManager")
	interface = dbus.Interface (proxy, "org.freedesktop.NetworkManager")
	base_connection = get_base_connection ()
	if base_connection is not None:
		interface.ActivateConnection('org.freedesktop.NetworkManagerUserSettings',
									 connection,
									 dbus.ObjectPath("/"),
									 base_connection)
	
if __name__ == "__main__":

	# If you turn vpn donw you probably don't
	# want me to fire it up again
	if sys.argv[2] == "vpn-down":
		sys.exit (0)
		
	# If you just tried to attach a VPN, you probably
	# don't want another one
	if sys.argv[2] == "vpn-up":
		sys.exit (0)
	

	# Preconnection scripts
	init ()
	
	# Obtain poisson vpn
	poisson_vpn = get_poisson_vpn ()
	
	# If poisson_vpn is None it means that it
	# is already active, so exit now
	if (poisson_vpn is None):
		sys.exit (0)
	
	# Activate connection
	activate_connection (poisson_vpn)
